import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement; 

/**
 * Demo program vor JDBC. 
 * Uses Derby as DB
 * @author hp
 */
public class Tests {
	
	public static void main(String[] args) {
		
		String url = "jdbc:derby:c:/Derby/test;create=true"; 
		Connection conn = null; 
		try {
			// Connect to DB
			conn = DriverManager.getConnection(url);
			
			// create table Person with columns id, firstName, lastName and born 
			Statement stmt = conn.createStatement(); 
			stmt.executeUpdate(
			"create table Person (id INTEGER PRIMARY KEY, firstname VARCHAR(128), lastName VARCHAR(128), born INTEGER)");
			
			// insert rows 
			PreparedStatement pStmt = conn.prepareStatement("insert into Person values(?, ?, ?, ?)"); 
			pStmt.setInt(1, 1);
			pStmt.setString(2, "Hermann");
			pStmt.setString(3, "Maier");
			pStmt.setInt(4, 1971);
			pStmt.executeUpdate(); 
			pStmt.setInt(1, 2);
			pStmt.setString(2, "Michael");
			pStmt.setString(3, "Walchhofer");
			pStmt.setInt(4, 1976);
			pStmt.executeUpdate(); 
			pStmt.setInt(1, 3);
			pStmt.setString(2, "Benni");
			pStmt.setString(3, "Raich");
			pStmt.setInt(4, 1978);
			pStmt.executeUpdate(); 
			pStmt.setInt(1, 4);
			pStmt.setString(2, "Mario");
			pStmt.setString(3, "Matt");
			pStmt.setInt(4, 1979);
			pStmt.executeUpdate(); 
			
			// update one row
			stmt.execute("update Person set born=1973 where id=1"); 

			// batch updates with prepared statement 
			pStmt.setInt(1, 5);
			pStmt.setString(2, "Mario");
			pStmt.setString(3, "Scheiber");
			pStmt.setInt(4, 1983);			
			pStmt.addBatch(); 

			pStmt.setInt(1, 6);
			pStmt.setString(2, "Rainer");
			pStmt.setString(3, "Schnfelder");
			pStmt.setInt(4, 1977);			
			pStmt.addBatch(); 
			int[] upds = pStmt.executeBatch(); 

			// batch updates with Statement
//			stmt.addBatch("insert into Person values(5, 'Mario', 'Scheiber', 1983)");			
//			stmt.addBatch("insert into Person values(6, 'Rainer', 'Schnfelder', 1977)");			
//			pStmt.addBatch(); 
//			int[] upds = stmt.executeBatch(); 
			
			System.out.println(); 
			System.out.println("-------- Person rows ----------------------------"); 
			// select Person rows with forward only ResultSet 
			ResultSet rs = stmt.executeQuery("select id, lastName, born from Person"); 
			while (rs.next()) {
				int nr = rs.getInt(1); 
				String lastName = rs.getString("lastName"); 
				int born = rs.getInt("born"); 
				System.out.println(nr + ": " + lastName + " born: " + born); 
			}
			
			// select Person rows with scrollable ResultSet 
			System.out.println(); 
			System.out.println("-------- Scrollable from 2 ----------------------------"); 
			Statement scrStmt = 
				conn.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY); 
			ResultSet scrRs = scrStmt.executeQuery("select id, lastName, born from Person"); 
			
			// put out rows after 2nd 
			scrRs.absolute(2); 
			while (scrRs.next()) {
				int nr = scrRs.getInt(1); 
				String lastName = scrRs.getString("lastName"); 
				int born = scrRs.getInt("born"); 
				System.out.println(nr + ": " + lastName + " born: " + born); 
			}
			
			// put out rows in reverse order  
			System.out.println(); 
			System.out.println("-------- Scrollable reverse ----------------------------"); 
			scrRs.afterLast(); 
			while (scrRs.previous()) {
				int nr = scrRs.getInt(1); 
				String lastName = scrRs.getString("lastName"); 
				int born = scrRs.getInt("born"); 
				System.out.println(nr + ": " + lastName + " born: " + born); 
			}
			
			// update ResultSet 
			Statement updStmt = conn.createStatement(ResultSet.TYPE_SCROLL_SENSITIVE, ResultSet.CONCUR_UPDATABLE); 
			ResultSet updRs = updStmt.executeQuery("select id, firstName, lastName, born from Person"); 
			updRs.absolute(3); 
			while (updRs.previous()) {
				int born = updRs.getInt("born"); 
				updRs.updateInt("born", born - 1); 
				updRs.updateRow(); 
			}
			
			// insert one new row 
			updRs.moveToInsertRow(); 
			updRs.updateInt(1, 7);
			updRs.updateString("firstName", "Chritoph");
			updRs.updateString("lastName", "Gruber");
			updRs.updateInt("born", 1976);
			updRs.insertRow(); 
			
			// delete first row 
			updRs.absolute(1); 
			updRs.deleteRow(); 
			
			// output all rows after update 
			System.out.println(); 
			System.out.println("-------- Person rows after update ----------------------------"); 
			rs = stmt.executeQuery("select id, firstName, lastName, born from Person"); 
			while (rs.next()) {
				int nr = rs.getInt(1); 
				String firstName = rs.getString("firstName"); 
				String lastName = rs.getString("lastName"); 
				int born = rs.getInt("born"); 
				System.out.println(nr + ": " + firstName + " " + lastName + " born: " + born); 
			}


		} catch (SQLException e) {
			 
			e.printStackTrace();
		} finally {
			try {
				conn.close();
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
	}

}
